@@ -55,7 +55,7 @@ define('AUTHNETAIM_TEST_POST_URL','https://test.authorize.net/gateway/transact.d
 class AuthNetAim extends CGPaymentGatewayBase
 {
 
-  var $_data;
+  protected $_data;
 
   /*---------------------------------------------------------
    Constructor()
@@ -72,7 +72,7 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function GetName()
   {
-    return 'AuthNetAim';
+    return get_class();
   }
 
   
@@ -90,7 +90,7 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function GetVersion()
   {
-    return '1.2.5';
+    return '1.2.6';
   }
 
 
@@ -670,4 +670,17 @@ class AuthNetAim extends CGPaymentGatewayBase
     return $this->DoAction('process_payment','cntnt01',$params);
   }
 
+
+  function GetNotificationOutput($priority=2)
+  {
+    global $CMS_ADMIN_PAGE;
+    $testmode = $this->GetPreference('testmode',1);
+    if( $testmode && check_login(FALSE) )
+      {
+	$data = new stdClass;
+	$data->priority = 1;
+	$data->html = $this->ShowErrors($this->Lang('msg_testmode'));
+	return $data;
+      }
+  }
 } // class
